==> input-range-scss-1.5.0.tgz: package/README.md <==
# Styling Cross-Browser Compatible Range Inputs with Sass / SCSS

Sass component for customizing the input range using the native properties of each browser. Based on article [Styling Cross-Browser Compatible Range Inputs with CSS](https://css-tricks.com/styling-cross-browser-compatible-range-inputs-css/) from CSS Tricks blog.

## NPM Package
```
npm install --save input-range-scss
```
## Features

-   Variables for easy customization
-   Uses the native properties of each browser
-   Preserves accessibility
-   Cross-browser compatible

## Example

![Input range native and custom on browsers](https://github.com/darlanrod/input-range-scss/raw/master/example/input-range-browsers.jpg)

## Changelog

#### 1.5.0
-   Added :disabled state (thanks [mpavel](https://github.com/mpavel))
-   Improved normalization across browsers (thanks [guidezpl](https://github.com/guidezpl) and [GufNZ](https://github.com/GufNZ))
-   Removed Firefox border outline on focus (thanks [DeanPoulin](https://github.com/DeanPoulin))

#### 1.4.1
-   Fixing example page

#### 1.4.0
-   NPM Package

#### 1.3.0
-   Better default style and example page

#### 1.2.0
-   Improvement in SCSS lint (thanks, [Dustin McCaffree](https://github.com/dMcCaffree))

#### 1.1.1
-   Fix track height in IE and thumb margin in Edge (thanks, [danclaydonpm](https://github.com/danclaydonpm) and [jenstornell](https://github.com/jenstornell))

#### 1.1.0
-   Make all variables as '!default'. (thanks, [n0nick](https://github.com/n0nick))

#### 1.0.1
-   SCSS-Lint fix. (thanks, [CookPete](https://github.com/CookPete))

## See Also

[Input range browser support](http://caniuse.com/#feat=input-range)

==> input-range-scss-1.5.1.tgz: package/README.md <==
# Styling Cross-Browser Compatible Range Inputs with Sass / SCSS

Sass component for customizing the input range using the native properties of each browser. Based on article [Styling Cross-Browser Compatible Range Inputs with CSS](https://css-tricks.com/styling-cross-browser-compatible-range-inputs-css/) from CSS Tricks blog.

## NPM Package
```
npm install --save input-range-scss
```
## Features

-   Variables for easy customization
-   Uses the native properties of each browser
-   Preserves accessibility
-   Cross-browser compatible

## Example

![Input range native and custom on browsers](https://github.com/darlanrod/input-range-scss/raw/master/example/input-range-browsers.jpg)

## Changelog

#### 1.5.1
-   Correction of input cursor to default (thanks, [pichfl](https://github.com/pichfl))

#### 1.5.0
-   Added :disabled state (thanks, [mpavel](https://github.com/mpavel))
-   Improved normalization across browsers (thanks, [guidezpl](https://github.com/guidezpl) and [GufNZ](https://github.com/GufNZ))
-   Removed Firefox border outline on focus (thanks, [DeanPoulin](https://github.com/DeanPoulin))

#### 1.4.1
-   Fixing example page

#### 1.4.0
-   NPM Package

#### 1.3.0
-   Better default style and example page

#### 1.2.0
-   Improvement in SCSS lint (thanks, [Dustin McCaffree](https://github.com/dMcCaffree))

#### 1.1.1
-   Fix track height in IE and thumb margin in Edge (thanks, [danclaydonpm](https://github.com/danclaydonpm) and [jenstornell](https://github.com/jenstornell))

#### 1.1.0
-   Make all variables as '!default'. (thanks, [n0nick](https://github.com/n0nick))

#### 1.0.1
-   SCSS-Lint fix. (thanks, [CookPete](https://github.com/CookPete))

## See Also

[Input range browser support](http://caniuse.com/#feat=input-range)
